@@ -212,35 +212,31 @@ impl FileOps for crate::files::Files {
             uri += "?uploadType=resumable&supportsAllDrives=true&includeItemsFromAllDrives=true";
 
             // Create the file.
+        } else if let Some(f) = files.get(0) {
+            method = reqwest::Method::PATCH;
+            let mut f = f.clone();
+            uri += &format!(
+                "/{}?uploadType=resumable&supportsAllDrives=true&includeItemsFromAllDrives=true",
+                f.id
+            );
+
+            f.id = "".to_string();
+            f.drive_id = "".to_string();
+            f.kind = "".to_string();
+            f.original_filename = f.name.to_string();
         } else {
-            if let Some(f) = files.get(0) {
-                method = reqwest::Method::PATCH;
-                let mut f = f.clone();
-                uri += &format!(
-                    "/{}?uploadType=resumable&supportsAllDrives=true&\
-                     includeItemsFromAllDrives=true",
-                    f.id
-                );
-
-                f.id = "".to_string();
-                f.drive_id = "".to_string();
-                f.kind = "".to_string();
-                f.original_filename = f.name.to_string();
+            // Set the name,
+            f.name = name.to_string();
+            f.mime_type = mime_type.to_string();
+            if !parent_id.is_empty() {
+                f.parents = vec![parent_id.to_string()];
             } else {
-                // Set the name,
-                f.name = name.to_string();
-                f.mime_type = mime_type.to_string();
-                if !parent_id.is_empty() {
-                    f.parents = vec![parent_id.to_string()];
-                } else {
-                    f.parents = vec![drive_id.to_string()];
-                }
-
-                uri +=
-                    "?uploadType=resumable&supportsAllDrives=true&includeItemsFromAllDrives=true";
-
-                // Create the file.
+                f.parents = vec![drive_id.to_string()];
             }
+
+            uri += "?uploadType=resumable&supportsAllDrives=true&includeItemsFromAllDrives=true";
+
+            // Create the file.
         }
 
         // Build the request to get the URL upload location if we need to create the file.
@@ -249,20 +245,20 @@ impl FileOps for crate::files::Files {
             .request_raw(
                 method,
                 &uri,
-                Some(reqwest::Body::from(serde_json::to_vec(&f).unwrap())),
+                Some(reqwest::Body::from(serde_json::to_vec(&f)?)),
             )
-            .await
-            .unwrap();
+            .await?;
 
         // Get the "Location" header.
-        let location = resp.headers().get("Location").unwrap().to_str().unwrap();
+        let location = match resp.headers().get("Location") {
+            Some(location) => location.to_str()?,
+            None => anyhow::bail!("No Location header"),
+        };
 
         // Now upload the file to that location.
-        Ok(self
-            .client
+        self.client
             .request_with_mime(reqwest::Method::PUT, location, contents, mime_type)
             .await
-            .unwrap())
     }
 
     /// Download a file by it's ID.
@@ -274,10 +270,9 @@ impl FileOps for crate::files::Files {
                 &format!("/files/{}?supportsAllDrives=true&alt=media", id),
                 None,
             )
-            .await
-            .unwrap();
+            .await?;
 
-        Ok(resp.bytes().await.unwrap())
+        Ok(resp.bytes().await?)
     }
 
     /// Create a folder, if it doesn't exist, returns the ID of the folder.
@@ -328,10 +323,9 @@ impl FileOps for crate::files::Files {
             .client
             .post(
                 "/files?supportsAllDrives=true&includeItemsFromAllDrives=true",
-                Some(reqwest::Body::from(serde_json::to_vec(&file).unwrap())),
+                Some(reqwest::Body::from(serde_json::to_vec(&file)?)),
             )
-            .await
-            .unwrap();
+            .await?;
 
         Ok(folder.id)
     }
@@ -349,16 +343,15 @@ impl FileOps for crate::files::Files {
         }
         let url = format!(
             "/files/{}/export?{}",
-            crate::progenitor_support::encode_path(&id.to_string()),
+            crate::progenitor_support::encode_path(id),
             query_
         );
         let resp = self
             .client
             .request_raw(reqwest::Method::GET, &url, None)
-            .await
-            .unwrap();
+            .await?;
 
-        Ok(resp.text().await.unwrap())
+        Ok(resp.text().await?)
     }
 
     /// Delete a file by its name.
@@ -398,8 +391,7 @@ impl DriveOps for crate::drives::Drives {
                 //&format!("name = '{}'", name), // query
                 "", true, // use domain admin access
             )
-            .await
-            .unwrap();
+            .await?;
 
         for drive in drives {
             if drive.name == name {
